import * as plugins from '../smartacme.plugins.js';
import type { ICertManager } from '../interfaces/certmanager.js';
import { SmartacmeCert } from '../smartacme.classes.cert.js';

/**
 * In-memory certificate manager for mongoless mode.
 * Stores certificates in memory only and does not connect to MongoDB.
 */
export class MemoryCertManager implements ICertManager {
  private certs: Map<string, SmartacmeCert> = new Map();


  public async init(): Promise<void> {
    // no-op for in-memory store
  }

  public async retrieveCertificate(domainName: string): Promise<SmartacmeCert | null> {
    return this.certs.get(domainName) ?? null;
  }

  public async storeCertificate(cert: SmartacmeCert): Promise<void> {
    this.certs.set(cert.domainName, cert);
  }

  public async deleteCertificate(domainName: string): Promise<void> {
    this.certs.delete(domainName);
  }

  public async close(): Promise<void> {
    // no-op
  }
  /**
   * Wipe all certificates from the in-memory store (for testing)
   */
  public async wipe(): Promise<void> {
    this.certs.clear();
  }
}